@@ -5,17 +5,16 @@
  */
 
 #include  "config.h"
+#include  "fetchmail.h"
+
 #include  <stdio.h>
 #include  <string.h>
 #include  <ctype.h>
-#if defined(STDC_HEADERS)
 #include  <stdlib.h>
-#endif
-#include  "fetchmail.h"
 #include  "socket.h"
 
 #include  "i18n.h"
-#include "fm_md5.h"
+#include  "fm_md5.h"
 
 void hmac_md5 (const unsigned char *password,  size_t pass_len,
                const unsigned char *challenge, size_t chal_len,
@@ -122,7 +121,7 @@ int do_cram_md5 (int sock, const char *command, struct query *ctl, const char *s
               response[8], response[9], response[10], response[11],
               response[12], response[13], response[14], response[15]);
 
-    to64frombits (buf1, reply, strlen(reply));
+    to64frombits (buf1, reply, strlen(reply), sizeof buf1);
 
     /* ship the authentication back, accept the server's responses */
     /* PMDF5.2 IMAP has a bug that requires this to be a single write */
