@@ -576,6 +576,22 @@ void stuff_warning(const char *,
     __attribute__ ((format (printf, 4, 5)))
     ;
 void close_warning_by_mail(struct query *, struct msgblk *);
+enum tlsmode_en { NOTLS, MAYSTARTTLS, STARTTLS, TLSWRAPPED };
+enum { SINK_HOSTNAME_PARTS = 5 };
+struct sink_host_st {
+        char *identifier;               /**< servername (DNS) to connect to */
+        char *servername;               /**< servername for TLS */
+        enum tlsmode_en tlsmode;        /**< tls mode */
+        const char *portname;           /**< portname, will not be NULL */
+        const char *tlsproto;           /**< tlsproto, can be NULL if missing */
+};
+#define SINKDATA_INITIALIZER {0, 0, MAYSTARTTLS, 0, 0}
+  /** split \a parsed_host (which will be modified) into components -- Syntax:
+   * hostname/{port|service}[/starttls|/tls|/notls][/tlsproto=xxx][/servername=XXX]
+   * \returns a \ref sink_host_st structure by value
+   */
+struct sink_host_st sink_parse_host(char *parsed_host /** will be modified through strtok_r */);
+
 
 /* rfc822.c: RFC822 header parsing */
 char *reply_hack(char *, const char *, size_t *);
@@ -773,7 +789,7 @@ const char *get_default_cert_path(void);
 const char *get_default_cert_file(void);
 
 /* regex_helper.c */
-int match_regex(const char *restrict regexpattern, const char *restrict ins);
+int regex_ere_search(const char *restrict regexpattern, const char *restrict ins);
 
 #define	NETRC_FILE	".netrc"
 
