@@ -641,8 +641,7 @@ static int pop3_getauth(int sock, struct query *ctl, char *greeting)
 	    report(stderr, GT_("We've run out of allowed authenticators and cannot continue.\n"));
 	    ok = PS_AUTHFAIL;
 	}
-	memset(shroud, 0x55, sizeof(shroud));
-	shroud[0] = '\0';
+	fm_safe_clearmem(shroud, sizeof(shroud));
 	break;
 
     case P_APOP:
@@ -686,7 +685,7 @@ static int pop3_getauth(int sock, struct query *ctl, char *greeting)
 	strcpy(msg,start);
 	strcat(msg,ctl->password);
 	strcpy((char *)ctl->digest, MD5Digest((unsigned char *)msg));
-	free(msg);
+	xzerofree(msg);
 
 	ok = gen_transact(sock, "APOP %s %s", ctl->remotename, (char *)ctl->digest);
 	break;
@@ -695,8 +694,7 @@ static int pop3_getauth(int sock, struct query *ctl, char *greeting)
 	if ((ok = gen_transact(sock,"USER %s", ctl->remotename)) == 0) {
 	    strlcpy(shroud, ctl->password, sizeof(shroud));
 	    ok = gen_transact(sock, "RPOP %s", ctl->password);
-	    memset(shroud, 0x55, sizeof(shroud));
-	    shroud[0] = '\0';
+	    fm_safe_clearmem(shroud, sizeof(shroud));
 	}
 	break;
 
