@@ -12,7 +12,7 @@
 
 static char buf2[] = TESTSTRING;
 
-int main() {
+int main(void) {
 	char *bufp1;
 	char *bufp2;
 	char *bufp3;
